@@ -14,6 +14,19 @@ from lightwood.data.encoded_ds import EncodedDs, ConcatedEncodedDs
 
 
 class Normalizer(BaseMixer):
+    """
+    Companion class to the confidence estimation analysis block. A normalizer is a secondary machine learning model
+    tasked with learning to estimate the "difficulty" that the main predictor will have with any problem instance.
+
+    The idea is that this model should emit higher scores for tougher predictions. All scores will be passed as a
+    normalizing factor to the conformal prediction framework, thus:
+      - widening bounds at the same confidence level if a prediction is harder
+      - tightening bounds at the same confidence level if a predictions is easier
+      
+    Reference:
+        Papadopoulos, H., Gammerman, A., & Vovk, V. (2008). Normalized nonconformity measures for regression Conformal Prediction.
+
+    """  # noqa
     def __init__(self, fit_params: dict):
         super(Normalizer, self).__init__(stop_after=fit_params['stop_after'])
 
@@ -24,7 +37,7 @@ class Normalizer(BaseMixer):
         self.target_dtype = fit_params['dtype_dict'][fit_params['target']]
         self.multi_ts_task = fit_params['is_multi_ts']
 
-        self.model = Ridge()
+        self.model = Ridge()  # @TODO: enable underlying model selection from JsonAI
         self.prepared = False
         self.prediction_cache = None
         self.bounds = (0.5, 1.5)
