@@ -8,13 +8,17 @@ from lightwood.encoder.time_series.helpers.common import MinMaxNormalizer, CatNo
 
 
 class ArrayEncoder(BaseEncoder):
+    """
+    Fits a normalizer for array data. To encode, `ArrayEncoder` returns a normalized window of previous data.
+    It can be used for generic arrays, as well as for handling historical target values in time series tasks.
+
+    :param stop_after: time budget in seconds.
+    :param window: expected length of array data.
+    """
+
     is_trainable_encoder: bool = True
 
     def __init__(self, stop_after: int, window: int = None, is_target: bool = False, original_type: dtype = None):
-        """
-        Fits a normalizer for a time series previous historical data.
-        When encoding, it returns a normalized window of previous data.
-        """
         super().__init__(is_target)
         self.stop_after = stop_after
         self.original_type = original_type
@@ -34,7 +38,7 @@ class ArrayEncoder(BaseEncoder):
             if priming_data[i] is None:
                 priming_data[i] = [0] * self.output_size
 
-        if self._prepared:
+        if self.is_prepared:
             raise Exception('You can only call "prepare" once for a given encoder.')
 
         if self.original_type in (dtype.categorical, dtype.binary):
@@ -47,10 +51,10 @@ class ArrayEncoder(BaseEncoder):
 
         self._normalizer.prepare(priming_data)
         self.output_size *= self._normalizer.output_size
-        self._prepared = True
+        self.is_prepared = True
 
-    def encode(self, column_data: Union[list, np.ndarray]) -> torch.Tensor:
-        if not self._prepared:
+    def encode(self, column_data: Union[list, np.ndarray, torch.Tensor]) -> torch.Tensor:
+        if not self.is_prepared:
             raise Exception('You need to call "prepare" before calling "encode" or "decode".')
 
         if isinstance(column_data, pd.Series):
@@ -63,4 +67,9 @@ class ArrayEncoder(BaseEncoder):
         data = torch.cat([self._normalizer.encode(column_data)], dim=-1)
         data[torch.isnan(data)] = 0.0
         data[torch.isinf(data)] = 0.0
+
         return data
+
+    def decode(self, data) -> torch.tensor:
+        decoded = data.tolist()
+        return decoded
