@@ -1,7 +1,7 @@
 from lightwood.encoder.categorical.multihot import MultiHotEncoder
 from lightwood.encoder.text.pretrained import PretrainedLangEncoder
 from lightwood.encoder.time_series.rnn import TimeSeriesEncoder
-from lightwood.encoder.time_series.plain import TimeSeriesPlainEncoder
+from lightwood.encoder.array.array import ArrayEncoder
 
 
-__all__ = ['MultiHotEncoder', 'PretrainedLangEncoder', 'TimeSeriesEncoder', 'TimeSeriesPlainEncoder']
+__all__ = ['MultiHotEncoder', 'PretrainedLangEncoder', 'TimeSeriesEncoder', 'ArrayEncoder']
