@@ -3,11 +3,10 @@ from typing import Iterable
 
 def can_be_nan_numeric(value: object) -> bool:
     """
-    Tells us if **value** might be nan or inf or some other numeric value\
-        (i.e. which can be cast as `float`) that is not actually a number.\
-        Name is vague because I'm not 100% sure of all the edge cases of numeric\
-        values that have number-like type behavior.
-    """
+    Determines if **value** might be `nan` or `inf` or some other numeric value (i.e. which can be cast as `float`) that is not actually a number.
+    
+    Name is vague due to uncertainty that all edge cases of numeric values that have number-like type behavior are covered.
+    """  # noqa
 
     try:
         value = str(value)
