@@ -29,7 +29,7 @@ def is_allowed(v):
         return True
 
     # Allowed variable names
-    if v in ['df', 'nsubsets', 'data', 'encoded_data', 'train_data', 'encoded_train_data', 'test_data']:
+    if v in ['df', 'data', 'encoded_data', 'train_data', 'encoded_train_data', 'test_data']:
         return True
 
     try:
